@@ -13,7 +13,7 @@ Cache::RedisDB - RedisDB based cache system
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 DESCRIPTION
 
@@ -21,7 +21,7 @@ This is just a warpper around RedisDB to have a single Redis object and connecti
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -49,11 +49,16 @@ Creates new connection to redis-server and returns corresponding RedisDB object.
 
 sub redis_connection {
     my ($server, $port) = split /:/, redis_server_info();
-    return RedisDB->new(
-        host               => $server,
-        port               => $port,
-        reconnect_attempts => 3,
-    );
+    my $redis;
+    eval {
+        $redis = RedisDB->new(
+            host               => $server,
+            port               => $port,
+            reconnect_attempts => 3
+        );
+    };
+    return if $@;
+    return $redis;
 }
 
 =head2 redis
